#ifndef __CHEBY__TESTER_WR_REGS__H__
#define __CHEBY__TESTER_WR_REGS__H__
#define TESTER_WR_REGS_SIZE 80

/* None */
#define TESTER_WR_REGS_DEV_ID 0x0UL
#define TESTER_WR_REGS_DEV_ID_SIZE 32

/* None */
#define TESTER_WR_REGS_DEV_ID_VENDOR_ID 0x0UL
#define TESTER_WR_REGS_DEV_ID_VENDOR_ID_PRESET 0x10dcUL

/* None */
#define TESTER_WR_REGS_DEV_ID_DEVICE_ID 0x4UL
#define TESTER_WR_REGS_DEV_ID_DEVICE_ID_PRESET 0x54535401UL

/* None */
#define TESTER_WR_REGS_DEV_ID_VERSION 0x8UL
#define TESTER_WR_REGS_DEV_ID_VERSION_PRESET 0x1UL

/* None */
#define TESTER_WR_REGS_DEV_ID_BOM 0xcUL
#define TESTER_WR_REGS_DEV_ID_BOM_PRESET 0xfffe0000UL

/* None */
#define TESTER_WR_REGS_DEV_ID_SOURCE_ID0 0x10UL
#define TESTER_WR_REGS_DEV_ID_SOURCE_ID0_PRESET 0x0UL

/* None */
#define TESTER_WR_REGS_DEV_ID_SOURCE_ID1 0x14UL
#define TESTER_WR_REGS_DEV_ID_SOURCE_ID1_PRESET 0x0UL

/* None */
#define TESTER_WR_REGS_DEV_ID_SOURCE_ID2 0x18UL
#define TESTER_WR_REGS_DEV_ID_SOURCE_ID2_PRESET 0x0UL

/* None */
#define TESTER_WR_REGS_DEV_ID_SOURCE_ID3 0x1cUL
#define TESTER_WR_REGS_DEV_ID_SOURCE_ID3_PRESET 0x0UL

/* General status */
#define TESTER_WR_REGS_STATUS 0x20UL
#define TESTER_WR_REGS_STATUS_TIME_VALID 0x1UL
#define TESTER_WR_REGS_STATUS_LINK_VALID 0x2UL

/* TAI from wr */
#define TESTER_WR_REGS_TM_TAI 0x28UL

/* number of cycles (16Mhz) within the second */
#define TESTER_WR_REGS_TM_CYCLES 0x30UL

/* absolute TAI (LSB) for interrupts */
#define TESTER_WR_REGS_START_TAI 0x34UL

/* absolute cycles for interrupts */
#define TESTER_WR_REGS_START_CYCLES 0x38UL

/* number of cycles between interrupts */
#define TESTER_WR_REGS_PERIOD_CYCLES 0x3cUL

/* number of interrupts to deliver */
#define TESTER_WR_REGS_TOTAL_COUNT 0x40UL

/* number of interrupts delivered. */
#define TESTER_WR_REGS_CURRENT_COUNT 0x44UL

/* the current number of interrupts must be written to ack the interrupt. */
#define TESTER_WR_REGS_ACK_INT 0x48UL

/* number of interrupts successfully ack-ed; cleared at the start */
#define TESTER_WR_REGS_ACK_COUNT 0x4cUL

struct tester_wr_regs {
  /* [0x0]: BLOCK (no description) */
  struct dev_id {
    /* [0x0]: REG (ro) (no description) */
    uint32_t vendor_id;

    /* [0x4]: REG (ro) (no description) */
    uint32_t device_id;

    /* [0x8]: REG (ro) (no description) */
    uint32_t version;

    /* [0xc]: REG (ro) (no description) */
    uint32_t bom;

    /* [0x10]: REG (ro) (no description) */
    uint32_t source_id0;

    /* [0x14]: REG (ro) (no description) */
    uint32_t source_id1;

    /* [0x18]: REG (ro) (no description) */
    uint32_t source_id2;

    /* [0x1c]: REG (ro) (no description) */
    uint32_t source_id3;
  } dev_id;

  /* [0x20]: REG (ro) General status */
  uint32_t status;

  /* padding to: 10 words */
  uint32_t __padding_0[1];

  /* [0x28]: REG (ro) TAI from wr */
  uint64_t tm_tai;

  /* [0x30]: REG (ro) number of cycles (16Mhz) within the second */
  uint32_t tm_cycles;

  /* [0x34]: REG (rw) absolute TAI (LSB) for interrupts */
  uint32_t start_tai;

  /* [0x38]: REG (rw) absolute cycles for interrupts */
  uint32_t start_cycles;

  /* [0x3c]: REG (rw) number of cycles between interrupts */
  uint32_t period_cycles;

  /* [0x40]: REG (rw) number of interrupts to deliver */
  uint32_t total_count;

  /* [0x44]: REG (ro) number of interrupts delivered. */
  uint32_t current_count;

  /* [0x48]: REG (wo) the current number of interrupts must be written to ack the interrupt. */
  uint32_t ack_int;

  /* [0x4c]: REG (ro) number of interrupts successfully ack-ed; cleared at the start */
  uint32_t ack_count;
};

#endif /* __CHEBY__TESTER_WR_REGS__H__ */
